pyparsing.pyparsing.White

Package pyparsing :: Module pyparsing :: Class White |
[frames] | no frames]

# Class White

source code

       object --+
                |
    ParserElement --+
                    |
                Token --+
                        |
                       White

Special matching class for matching whitespace. Normally, whitespace is ignored by pyparsing grammars. This class is included when some whitespace structures are significant. Define with a string containing the whitespace characters to be matched; default is " \t\n". Also takes optional min, max, and exact arguments, as defined for the Word class.

Instance Methods
__init__(self, ws=`'``\t\r\n``'`, min=1, max=0, exact=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
parseImpl(self, instring, loc, doActions=True) | source code
Inherited from `Token`: `setName` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__hash__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rsub__`, `__rxor__`, `__str__`, `__sub__`, `__xor__`, `addParseAction`, `checkRecursion`, `copy`, `getException`, `ignore`, `leaveWhitespace`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `streamline`, `suppress`, `transformString`, `tryParse`, `validate` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
| whiteStrs = ``{``'``\t``'``:` `'``<TAB>``'``,` `'``\n``'``:` `'``<LF>``'``,` `'``\x0c``'``:` `'``<FF>``'``,` `'``\r``'``...``
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, ws=`'``\t\r\n``'`, min=1, max=0, exact=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### parseImpl(self, instring, loc, doActions=True) | source code
Overrides: ParserElement.parseImpl

Class Variable Details

  ### whiteStrs Value:
      {'\t': '<TAB>',
       '''
      ''': '<LF>',
       '\x0c': '<FF>',
       '\r': '<CR>',
       ' ': '<SPC>'}